/*
 * @(#)ChargedFluidIndex.java		1.10 07/01/20
 *
 * ChargedFluid package
 *
 * COPYRIGHT NOTICE
 * Copyright (c) 2007 Herbert H.H. Chang, Daniel J. Valentino, Gary R. Duckwiler, and Arthur W. Toga
 * Laboratory of Neuro Imaging, Department of Neurology, UCLA.
 */
 
package tools;

/**
 * The <code>ChargedFluidIndex</code> class contains the index of a specified 
 * <code>ChargedFluid</code>, which is used for the connection of overlapped charged
 * fluids in constructing the corresponding <code>Poisson</code>.
 */
public class ChargedFluidIndex
{
	/** 
	 * The index for the charged fluid. 
	 */
	private int _index;
	
  	/** 
  	 * True, if the charged fluid is integrated. 
  	 */
  	private boolean _isNotIntegrated = true;
  	
	
	/** 
	 * Constructs a charged fluid index with the sepcified index.
	 * @param	index	the charged fluid index.
	 */
  	public ChargedFluidIndex(int index)
  	{
    	_index = index;
  	}
	
	
	/** 
	 * Sets the <tt>_isNotIntegrated</tt> property, which decides whether the charged fluid
	 * is integrated with others or not.
	 * @param	isNotIntegrated		<tt>true</tt> if the charged fluid is not integrated.
	 */
	public void setIndexIsNotIntegrated(boolean isNotIntegrated)
	{
		_isNotIntegrated = isNotIntegrated;	
	}
	
	
	/**
	 * Determines whether the charged fluid is integrated or not.
	 * @return	<code>true</code> if the charged fluid is not integrated.
	 */
	public boolean isNotIntegrated()
	{
		return _isNotIntegrated;
	}
	
	
	/** 
	 * Returns the index of the charged fluid.
	 * @return		the charged fluid index.
	 */
	public int getIndex()
	{
		return _index;
	}
}